#[non_exhaustive]pub enum ReCaptchaErrorCode {
MissingInputSecret,
InvalidInputSecret,
MissingInputResponse,
InvalidInputResponse,
BadRequest,
TimeoutOrDuplicate,
Other(String),
}Expand description
An error code reported by the siteverify API.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
MissingInputSecret
The secret key is not set.
InvalidInputSecret
The secret key is invalid or malformed.
MissingInputResponse
The reCAPTCHA token is not set.
InvalidInputResponse
The reCAPTCHA token is invalid or malformed.
BadRequest
The request is invalid or malformed.
TimeoutOrDuplicate
The reCAPTCHA token is no longer valid, because it is either too old or has been used before.
Other(String)
An error code this crate does not know about.
Implementations